==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-portal-base/dictionaries/nl.dict.itop-portal-base.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', [
	'Brick:Portal:AggregatePage:DefaultTitle' => 'Dashboard',
	'Brick:Portal:Browse:Action:Create' => 'Aanmaken',
	'Brick:Portal:Browse:Action:CreateObjectFromThis' => 'Nieuw %1$s',
	'Brick:Portal:Browse:Action:Drilldown' => 'Drilldown',
	'Brick:Portal:Browse:Action:Edit' => 'Wijzigen',
	'Brick:Portal:Browse:Action:View' => 'Details',
	'Brick:Portal:Browse:Filter:NoData' => 'Geen gegevens',
	'Brick:Portal:Browse:Mode:List' => 'Lijst',
	'Brick:Portal:Browse:Mode:Mosaic' => 'Mozaïek',
	'Brick:Portal:Browse:Mode:Tree' => 'Boomstructuur',
	'Brick:Portal:Browse:Name' => 'Bladeren',
	'Brick:Portal:Browse:Tree:CollapseAll' => 'Verberg alles',
	'Brick:Portal:Browse:Tree:ExpandAll' => 'Toon alles',
	'Brick:Portal:Create:ChooseType' => 'Geef een type op.',
	'Brick:Portal:Create:Name' => 'Snel aanmaken',
	'Brick:Portal:Filter:Name' => 'Voorfilteren van een bouwsteen',
	'Brick:Portal:Filter:SearchInput:Placeholder' => 'bv. wifi-verbinding',
	'Brick:Portal:Filter:SearchInput:Submit' => 'Zoek',
	'Brick:Portal:Manage:All' => 'Alles',
	'Brick:Portal:Manage:DisplayMode:bar-chart' => 'Staafgrafiek',
	'Brick:Portal:Manage:DisplayMode:list' => 'Lijst',
	'Brick:Portal:Manage:DisplayMode:pie-chart' => 'Taartgrafiek',
	'Brick:Portal:Manage:Group' => 'Groep',
	'Brick:Portal:Manage:Name' => 'Beheer items',
	'Brick:Portal:Manage:Others' => 'Andere',
	'Brick:Portal:Manage:Table:ItemActions' => 'Acties',
	'Brick:Portal:Manage:Table:NoData' => 'Geen gegevens',
	'Brick:Portal:Manage:fct:avg' => 'Gemiddelde',
	'Brick:Portal:Manage:fct:count' => 'Totaal',
	'Brick:Portal:Manage:fct:max' => 'Max',
	'Brick:Portal:Manage:fct:min' => 'Min',
	'Brick:Portal:Manage:fct:sum' => 'Som',
	'Brick:Portal:Object:Copy:CopiedTooltip' => 'Gekopieerd',
	'Brick:Portal:Object:Copy:TextToCopy' => '%2$s',
	'Brick:Portal:Object:Copy:Tooltip' => 'Kopieer link naar object',
	'Brick:Portal:Object:Form:Create:Title' => 'Nieuw %1$s',
	'Brick:Portal:Object:Form:Edit:Title' => 'Verwerken %2$s (%1$s)',
	'Brick:Portal:Object:Form:Message:ObjectSaved' => '%1$s opgeslagen',
	'Brick:Portal:Object:Form:Message:Saved' => 'Opgeslagen',
	'Brick:Portal:Object:Form:Stimulus:Title' => 'Vul de volgende informatie in:',
	'Brick:Portal:Object:Form:View:Title' => '%1$s : %2$s',
	'Brick:Portal:Object:Name' => 'Object',
	'Brick:Portal:Object:Search:Hierarchy:Title' => 'Selecteer %1$s (%2$s)',
	'Brick:Portal:Object:Search:Regular:Title' => 'Geselecteerd %1$s (%2$s)',
	'Brick:Portal:UserProfile:Name' => 'Gebruikersprofiel',
	'Brick:Portal:UserProfile:Navigation:Dropdown:Logout' => 'Uitloggen',
	'Brick:Portal:UserProfile:Navigation:Dropdown:MyProfil' => 'Mijn profiel',
	'Brick:Portal:UserProfile:Password:CantChangeContactAdministrator' => 'Neem contact op met de beheerder om jouw wachtwoord te wijzgen',
	'Brick:Portal:UserProfile:Password:CantChangeForUnknownReason' => 'Jouw wachtwoord kan niet gewijzigd worden. Neem contact op met de beheerder',
	'Brick:Portal:UserProfile:Password:ChoosePassword' => 'Nieuw wachtwoord',
	'Brick:Portal:UserProfile:Password:ConfirmPassword' => 'Bevestig nieuw wachtwoord',
	'Brick:Portal:UserProfile:Password:Title' => 'Wachtwoord',
	'Brick:Portal:UserProfile:PersonalInformations:Title' => 'Persoonlijke informatie',
	'Brick:Portal:UserProfile:Photo:Title' => 'Foto',
	'Error:HTTP:400' => 'Ongeldig verzoek',
	'Error:HTTP:401' => 'Aanmelden is vereist',
	'Error:HTTP:404' => 'Pagina kan niet worden gevonden',
	'Error:HTTP:500' => 'Oeps! Er is een fout opgetreden',
	'Error:HTTP:GetHelp' => 'Neem contact op met de beheerder als dit probleem zich blijft voordoen',
	'Error:XHR:Fail' => 'De data kan niet worden geladen, neem contact op met de beheerder',
	'Page:DefaultTitle' => '%1$s Gebruikersportaal',
	'Page:GoPortalHome' => 'Startpagina',
	'Page:GoPreviousPage' => 'Vorige pagina',
	'Page:Home' => 'Welkom',
	'Page:PleaseWait' => 'Even geduld...',
	'Page:ReloadPage' => 'Pagina herladen',
	'Portal:Attachments:DropZone:Message' => 'Sleep jouw bestanden hier om ze toe te voegen',
	'Portal:Autocomplete:NoResult' => 'Geen data',
	'Portal:Button:Add' => 'Toevoegen',
	'Portal:Button:Apply' => 'Update',
	'Portal:Button:Cancel' => 'Afbreken',
	'Portal:Button:Close' => 'Sluiten',
	'Portal:Button:Delete' => 'Verwijderen',
	'Portal:Button:Remove' => 'Verwijderen',
	'Portal:Button:Submit' => 'Verstuur',
	'Portal:Calendar-FirstDayOfWeek' => 'nl',
	'Portal:Datatables:Language:DisplayLength:All' => 'Alles',
	'Portal:Datatables:Language:EmptyTable' => 'Geen data beschikbaar in deze tabel',
	'Portal:Datatables:Language:Info' => 'Pagina _PAGE_ van _PAGES_',
	'Portal:Datatables:Language:InfoEmpty' => 'Geen informatie',
	'Portal:Datatables:Language:InfoFiltered' => 'gefilterd van _MAX_ items',
	'Portal:Datatables:Language:LengthMenu' => 'Toon _MENU_ items per pagina',
	'Portal:Datatables:Language:Paginate:First' => 'Eerste',
	'Portal:Datatables:Language:Paginate:Last' => 'Laatste',
	'Portal:Datatables:Language:Paginate:Next' => 'Volgende',
	'Portal:Datatables:Language:Paginate:Previous' => 'Vorige',
	'Portal:Datatables:Language:Processing' => 'Even geduld...',
	'Portal:Datatables:Language:Search' => 'Filter :',
	'Portal:Datatables:Language:Sort:Ascending' => 'inschakelen voor een oplopende sortering',
	'Portal:Datatables:Language:Sort:Descending' => 'inschakelen voor een aflopende sortering',
	'Portal:Datatables:Language:ZeroRecords' => 'Geen resultaten',
	'Portal:EnvironmentBanner:GoToProduction' => 'Keer terug naar de productie-omgeving',
	'Portal:EnvironmentBanner:Title' => 'Je werkt momenteel in de <strong>%1$s</strong>-omgeving',
	'Portal:Error:ObjectCannotBeCreated' => 'Fout: object kan niet worden aangemaakt. Kijk verwante objecten en bijlagen na vooraleer dit formulier opnieuw te versturen.',
	'Portal:Error:ObjectCannotBeUpdated' => 'Fout: object kan niet worden aangepast. Kijk verwante objecten en bijlagen na vooraleer dit formulier opnieuw te versturen.',
	'Portal:ErrorUserLoggedOut' => 'Je bent afgemeld en moet opnieuw aanmelden om verder te kunnen werken.',
	'Portal:File:DisplayInfo' => '<a href="%2$s" class="file_download_link">%1$s</a>',
	'Portal:File:DisplayInfo+' => '%1$s (%2$s) <a href="%3$s" class="file_open_link" target="_blank">Open</a> / <a href="%4$s" class="file_download_link">Download</a>',
	'Portal:File:None' => 'Geen bestand',
	'Portal:Form:Caselog:Entry:Close:Tooltip' => 'Sluit dit item.',
	'Portal:Form:Close:Warning' => 'Ben je zeker dat je dit venster wil sluiten? Ingevoerde gegevens kunnen verloren gaan.',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-portal-base/dictionaries/nl.dict.itop-portal-base.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Page:DefaultTitle' => '%1$s Gebruikersportaal',
	'Page:PleaseWait' => 'Even geduld...',
	'Page:Home' => 'Welkom',
	'Page:GoPortalHome' => 'Startpagina',
	'Page:GoPreviousPage' => 'Vorige pagina',
	'Page:ReloadPage' => 'Pagina herladen',
	'Portal:Button:Submit' => 'Verstuur',
	'Portal:Button:Apply' => 'Update',
	'Portal:Button:Cancel' => 'Afbreken',
	'Portal:Button:Close' => 'Sluiten',
	'Portal:Button:Add' => 'Toevoegen',
	'Portal:Button:Remove' => 'Verwijderen',
	'Portal:Button:Delete' => 'Verwijderen',
	'Portal:EnvironmentBanner:Title' => 'Je werkt momenteel in de <strong>%1$s</strong>-omgeving',
	'Portal:EnvironmentBanner:GoToProduction' => 'Keer terug naar de productie-omgeving',
	'Error:HTTP:400' => 'Ongeldig verzoek',
	'Error:HTTP:401' => 'Aanmelden is vereist',
	'Error:HTTP:404' => 'Pagina kan niet worden gevonden',
	'Error:HTTP:500' => 'Oeps! Er is een fout opgetreden',
	'Error:HTTP:GetHelp' => 'Neem contact op met de beheerder als dit probleem zich blijft voordoen',
	'Error:XHR:Fail' => 'De data kan niet worden geladen, neem contact op met de beheerder',
	'Portal:ErrorUserLoggedOut' => 'Je bent afgemeld en moet opnieuw aanmelden om verder te kunnen werken.',
	'Portal:Datatables:Language:Processing' => 'Even geduld...',
	'Portal:Datatables:Language:Search' => 'Filter :',
	'Portal:Datatables:Language:LengthMenu' => 'Toon _MENU_ items per pagina',
	'Portal:Datatables:Language:ZeroRecords' => 'Geen resultaten',
	'Portal:Datatables:Language:Info' => 'Pagina _PAGE_ van _PAGES_',
	'Portal:Datatables:Language:InfoEmpty' => 'Geen informatie',
	'Portal:Datatables:Language:InfoFiltered' => 'gefilterd van _MAX_ items',
	'Portal:Datatables:Language:EmptyTable' => 'Geen data beschikbaar in deze tabel',
	'Portal:Datatables:Language:DisplayLength:All' => 'Alles',
	'Portal:Datatables:Language:Paginate:First' => 'Eerste',
	'Portal:Datatables:Language:Paginate:Previous' => 'Vorige',
	'Portal:Datatables:Language:Paginate:Next' => 'Volgende',
	'Portal:Datatables:Language:Paginate:Last' => 'Laatste',
	'Portal:Datatables:Language:Sort:Ascending' => 'inschakelen voor een oplopende sortering',
	'Portal:Datatables:Language:Sort:Descending' => 'inschakelen voor een aflopende sortering',
	'Portal:Autocomplete:NoResult' => 'Geen data',
	'Portal:Attachments:DropZone:Message' => 'Sleep jouw bestanden hier om ze toe te voegen',
	'Portal:File:None' => 'Geen bestand',
	'Portal:File:DisplayInfo' => '<a href="%2$s" class="file_download_link">%1$s</a>',
	'Portal:File:DisplayInfo+' => '%1$s (%2$s) <a href="%3$s" class="file_open_link" target="_blank">Open</a> / <a href="%4$s" class="file_download_link">Download</a>',
	'Portal:Calendar-FirstDayOfWeek' => 'nl', //work with moment.js locales
));

// Object form
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Portal:Form:Caselog:Entry:Close:Tooltip' => 'Sluit dit item.',
	'Portal:Form:Close:Warning' => 'Ben je zeker dat je dit venster wil sluiten? Ingevoerde gegevens kunnen verloren gaan.',
	'Portal:Error:ObjectCannotBeCreated' => 'Fout: object kan niet worden aangemaakt. Kijk verwante objecten en bijlagen na vooraleer dit formulier opnieuw te versturen.',
	'Portal:Error:ObjectCannotBeUpdated' => 'Fout: object kan niet worden aangepast. Kijk verwante objecten en bijlagen na vooraleer dit formulier opnieuw te versturen.',
));

// UserProfile brick
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Brick:Portal:UserProfile:Name' => 'Gebruikersprofiel',
	'Brick:Portal:UserProfile:Navigation:Dropdown:MyProfil' => 'Mijn profiel',
	'Brick:Portal:UserProfile:Navigation:Dropdown:Logout' => 'Uitloggen',
	'Brick:Portal:UserProfile:Password:Title' => 'Wachtwoord',
	'Brick:Portal:UserProfile:Password:ChoosePassword' => 'Nieuw wachtwoord',
	'Brick:Portal:UserProfile:Password:ConfirmPassword' => 'Bevestig nieuw wachtwoord',
	'Brick:Portal:UserProfile:Password:CantChangeContactAdministrator' => 'Neem contact op met de beheerder om jouw wachtwoord te wijzgen',
	'Brick:Portal:UserProfile:Password:CantChangeForUnknownReason' => 'Jouw wachtwoord kan niet gewijzigd worden. Neem contact op met de beheerder',
	'Brick:Portal:UserProfile:PersonalInformations:Title' => 'Persoonlijke informatie',
	'Brick:Portal:UserProfile:Photo:Title' => 'Foto',
));

// AggregatePageBrick
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Brick:Portal:AggregatePage:DefaultTitle' => 'Dashboard',
));

// BrowseBrick brick
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Brick:Portal:Browse:Name' => 'Bladeren',
	'Brick:Portal:Browse:Mode:List' => 'Lijst',
	'Brick:Portal:Browse:Mode:Tree' => 'Boomstructuur',
	'Brick:Portal:Browse:Mode:Mosaic' => 'Mozaïek',
	'Brick:Portal:Browse:Action:Drilldown' => 'Drilldown',
	'Brick:Portal:Browse:Action:View' => 'Details',
	'Brick:Portal:Browse:Action:Edit' => 'Wijzigen',
	'Brick:Portal:Browse:Action:Create' => 'Aanmaken',
	'Brick:Portal:Browse:Action:CreateObjectFromThis' => 'Nieuw %1$s',
	'Brick:Portal:Browse:Tree:ExpandAll' => 'Toon alles',
	'Brick:Portal:Browse:Tree:CollapseAll' => 'Verberg alles',
	'Brick:Portal:Browse:Filter:NoData' => 'Geen gegevens',
));

// ManageBrick brick
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Brick:Portal:Manage:Name' => 'Beheer items',
	'Brick:Portal:Manage:Table:NoData' => 'Geen gegevens',
	'Brick:Portal:Manage:Table:ItemActions' => 'Acties',
	'Brick:Portal:Manage:DisplayMode:list' => 'Lijst',
	'Brick:Portal:Manage:DisplayMode:pie-chart' => 'Taartgrafiek',
	'Brick:Portal:Manage:DisplayMode:bar-chart' => 'Staafgrafiek',
	'Brick:Portal:Manage:Others' => 'Andere',
	'Brick:Portal:Manage:All' => 'Alles',
	'Brick:Portal:Manage:Group' => 'Groep',
	'Brick:Portal:Manage:fct:count' => 'Totaal',
	'Brick:Portal:Manage:fct:sum' => 'Som',
	'Brick:Portal:Manage:fct:avg' => 'Gemiddelde',
	'Brick:Portal:Manage:fct:min' => 'Min',
	'Brick:Portal:Manage:fct:max' => 'Max',
));

// ObjectBrick brick
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Brick:Portal:Object:Name' => 'Object',
	'Brick:Portal:Object:Form:Create:Title' => 'Nieuw %1$s',
	'Brick:Portal:Object:Form:Edit:Title' => 'Verwerken %2$s (%1$s)',
	'Brick:Portal:Object:Form:View:Title' => '%1$s : %2$s',
	'Brick:Portal:Object:Form:Stimulus:Title' => 'Vul de volgende informatie in:',
	'Brick:Portal:Object:Form:Message:Saved' => 'Opgeslagen',
	'Brick:Portal:Object:Form:Message:ObjectSaved' => '%1$s opgeslagen',
	'Brick:Portal:Object:Search:Regular:Title' => 'Geselecteerd %1$s (%2$s)',
	'Brick:Portal:Object:Search:Hierarchy:Title' => 'Selecteer %1$s (%2$s)',
	'Brick:Portal:Object:Copy:TextToCopy' => '%2$s',
	'Brick:Portal:Object:Copy:Tooltip' => 'Kopieer link naar object',
	'Brick:Portal:Object:Copy:CopiedTooltip' => 'Gekopieerd'
));

// CreateBrick brick
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Brick:Portal:Create:Name' => 'Snel aanmaken',
	'Brick:Portal:Create:ChooseType' => 'Geef een type op.',
));

// Filter brick
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Brick:Portal:Filter:Name' => 'Voorfilteren van een bouwsteen',
	'Brick:Portal:Filter:SearchInput:Placeholder' => 'bv. wifi-verbinding',
	'Brick:Portal:Filter:SearchInput:Submit' => 'Zoek',
));
